/***********************************************************************
 * YoLink Homebridge Platform class
 *
 * Copyright (c) 2022-2023 David Kerr
 *
 * Based on https://github.com/homebridge/homebridge-plugin-template
 *
 * This class is the main constructor for the plugin.
 */
import { API, DynamicPlatformPlugin, Logger, PlatformAccessory, PlatformConfig, Service, Characteristic } from 'homebridge';
import { YoLinkAPI } from './yolinkAPI';
import Semaphore from 'semaphore-promise';
export type YoLinkDevice = {
    deviceId: string;
    deviceUDID: string;
    name: string;
    token: string;
    type: string;
    parentDeviceId: string;
    modelName: string;
    deviceMsgName: string;
    semaphore: Semaphore;
    [key: string]: any;
};
export declare class YoLinkHomebridgePlatform implements DynamicPlatformPlugin {
    readonly log: Logger;
    readonly config: PlatformConfig;
    readonly api: API;
    readonly Service: typeof Service;
    readonly Characteristic: typeof Characteristic;
    private readonly accessories;
    private readonly deviceAccessories;
    private readonly knownDevices;
    private readonly addDeviceSemaphore;
    initializeCount: number;
    readonly yolinkAPI: YoLinkAPI;
    readonly yolinkRequestSemaphore: Semaphore;
    reportError: string;
    /*********************************************************************
     * constructor
     *
     */
    constructor(log: Logger, config: PlatformConfig, api: API);
    /*********************************************************************
     * This function is invoked when homebridge restores cached accessories
     * from disk at startup.
     */
    configureAccessory(accessory: PlatformAccessory): void;
    /*********************************************************************
     * verboseLog
     */
    verboseLog(msg: string): void;
    /*********************************************************************
     * liteLog
     */
    liteLog(msg: string): void;
    /*********************************************************************
     * makeBoolean
     * Allow for both 'true' as a boolean and "true" as a string to equal
     * true.  And provide a default for when it is undefined.
     */
    makeBoolean(a: any, b: boolean): boolean;
    /*********************************************************************
     * discoverDevices
     */
    discoverDevices(): Promise<void>;
    /*********************************************************************
     * registerDevices
     */
    registerDevices(): Promise<void>;
    /*********************************************************************
     * checkAddDevice
     */
    checkAddDevice(device: YoLinkDevice): void;
    /*********************************************************************
     * addDevice
     */
    addDevice(device: YoLinkDevice, uuid: string, existingAccessory: PlatformAccessory | undefined, device2?: YoLinkDevice | undefined): PlatformAccessory;
    /*********************************************************************
     * deleteRemovedDevices
     */
    removeDeletedDevices(deviceList: YoLinkDevice[]): void;
    /*********************************************************************
     * checkNewDevices
     */
    checkNewDevice(deviceId?: string | undefined): Promise<boolean>;
    /*********************************************************************
     * registerMqtt
     */
    registerMqtt(): Promise<void>;
}
//# sourceMappingURL=platform.d.ts.map